@@ -26,18 +26,8 @@
 #include <mtm/mtm-gui-handler.h>
 #include <mtm/mtm-ext.h>
 #include <glade/glade-xml.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkoptionmenu.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkvbox.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/gnome-file-entry.h>
-#include <libgnomeui/gnome-pixmap.h>
+#include <gtk/gtk.h>
+#include <gnome.h>
 #include "editor-page.h"
 
 #define GLADE_FILENAME "metatheme-edit.glade"
@@ -53,7 +43,6 @@ struct _EditorPagePrivate
 	MtmExt *ext;
 };
 
-static void editor_page_ext_changed (MtmConfigGui *gui, MtmExt *ext, EditorPage *page);
 static void editor_page_ext_enabled (GtkToggleButton *button, EditorPage *page);
 static void editor_page_set_file_list (MtmConfigGui *gui, const gchar **file_list, EditorPage *page);
 static void file_changed_cb (GtkWidget *item, EditorPage *page);
@@ -93,7 +82,7 @@ editor_page_init (GtkObject *object)
 	page->priv = g_new0 (EditorPagePrivate, 1);
 	/* Is having a GladeXML copy for each pane costly? I dunno. */
 	/* Next line useful for quick changes in UI */
-	if (g_file_exists (GLADE_FILENAME))
+	if (g_file_test (GLADE_FILENAME, G_FILE_TEST_EXISTS))
 		page->priv->xml = glade_xml_new (GLADE_FILENAME, "vbox11", NULL);
 	if (!page->priv->xml)
 		page->priv->xml = glade_xml_new (SHAREDIR GLADE_FILENAME, "vbox11", NULL);
@@ -106,50 +95,60 @@ editor_page_init (GtkObject *object)
 	gtk_box_pack_start (GTK_BOX (page), w, TRUE, TRUE, 0);
 
 	w = glade_xml_get_widget (page->priv->xml, "enabled_checkbutton");
-	gtk_signal_connect (GTK_OBJECT (w), "toggled", editor_page_ext_enabled, page);
+	g_signal_connect (G_OBJECT (w), "toggled", (GCallback) editor_page_ext_enabled, page);
 
-	pixfile = gnome_pixmap_file ("32_butteflylogo.png");
+	pixfile = gnome_program_locate_file (gnome_program_get (),
+					     GNOME_FILE_DOMAIN_PIXMAP,
+					     "32_butteflylogo.png", TRUE,
+					     NULL);
 	if (pixfile)
 	{
 		w = glade_xml_get_widget (page->priv->xml, "left_pixmap_holder");
 		gtk_box_pack_start (GTK_BOX (w),
-				    gnome_pixmap_new_from_file (pixfile),
+				    gtk_image_new_from_file (pixfile),
 				    TRUE, TRUE, 0);
 		g_free (pixfile);
 	}
 	
-	pixfile = gnome_pixmap_file ("settings.png");
+	pixfile = gnome_program_locate_file (gnome_program_get (),
+					     GNOME_FILE_DOMAIN_PIXMAP,
+					     "settings.png", TRUE,
+					     NULL);
 	if (pixfile)
 	{
 		w = glade_xml_get_widget (page->priv->xml, "right_pixmap_holder");
 		gtk_box_pack_start (GTK_BOX (w),
-				    gnome_pixmap_new_from_file (pixfile),
+				    gtk_image_new_from_file (pixfile),
 				    TRUE, TRUE, 0);
 		g_free (pixfile);
 	}
 }
 
 
-GtkType
+GType
 editor_page_get_type (void)
 {
-	static GtkType type = 0;
+	static GType type = 0;
 
 	if (!type)
 	{
-		GtkTypeInfo info =
+		GTypeInfo info =
 		{
-			"EditorPage",
-			sizeof (EditorPage),
 			sizeof (EditorPageClass),
-			(GtkClassInitFunc) editor_page_class_init,
-			(GtkObjectInitFunc) editor_page_init,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL
+			NULL,
+			NULL,
+			(GClassInitFunc) editor_page_class_init,
+			NULL,
+			NULL,
+			sizeof (MtmExtHandler),
+			0,	
+			(GInstanceInitFunc) editor_page_init,
+			NULL
 		};
 
-		type = gtk_type_unique (gtk_vbox_get_type (), &info);
+		type = g_type_register_static (GTK_TYPE_VBOX,
+					       "EditorPage",
+					       &info, 0);
 	}
 
 	return type;
@@ -160,7 +159,7 @@ editor_page_new (void)
 {
 	EditorPage *page;
 
-	page = gtk_type_new (editor_page_get_type ());
+	page = g_object_new (editor_page_get_type (), NULL);
 	return GTK_WIDGET (page);
 }
 
@@ -201,8 +200,8 @@ editor_page_new_from_type (MtmEnv *env, gchar *type)
 	page->priv->entry = entry;
 	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (page->priv->xml, "file_list_hbox")), entry, TRUE, TRUE, 0);
 	
-	gtk_signal_connect (GTK_OBJECT (entry), "activate", file_changed_cb, page);
-	gtk_signal_connect (GTK_OBJECT (GTK_COMBO (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (entry)))->list), "selection_changed", selected_cb, page);
+	g_signal_connect (G_OBJECT (entry), "activate", (GCallback) file_changed_cb, page);
+	g_signal_connect (G_OBJECT (GTK_COMBO (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (entry)))->list), "selection_changed", (GCallback) selected_cb, page);
 
 	if (!handler)
 	{
@@ -225,9 +224,9 @@ editor_page_new_from_type (MtmEnv *env, gchar *type)
 		editor_page_add_no_info (page);
 	}
 
-	gtk_signal_connect (GTK_OBJECT (page->priv->gui), "set_file_list", editor_page_set_file_list, page);
+	g_signal_connect (G_OBJECT (page->priv->gui), "set_file_list", (GCallback) editor_page_set_file_list, page);
 	/* Of course, by now the initial one is already set */
-	editor_page_set_file_list (page->priv->gui, page->priv->gui->file_list, page); 
+	editor_page_set_file_list (page->priv->gui, (const gchar**) page->priv->gui->file_list, page); 
 
 	return GTK_WIDGET (page);
 }
@@ -243,7 +242,11 @@ editor_page_new_from_ext (MtmExt *ext)
 	
 	/* Set it before the gui hears it */
 	if (ext->file)
-		gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (page->priv->entry))), g_basename (ext->file));
+	{
+		gchar *base = g_path_get_basename (ext->file);
+		gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (page->priv->entry))), base);
+		g_free (base);
+	}
 
 	if (page->priv->gui)
 		mtm_config_gui_set_ext (page->priv->gui, ext);
@@ -283,11 +286,13 @@ file_changed_cb (GtkWidget *item, EditorPage *page)
 		return;
 	if (!g_file_test (file, G_FILE_TEST_IS_DIR))
 	{
-		gchar *tmp = ext->handler->find (ext->handler, g_basename (file), FALSE);
+		gchar *base = g_path_get_basename (file);
+		gchar *tmp = ext->handler->find (ext->handler, base, FALSE);
 		if (!tmp)
-			tmp = ext->handler->find (ext->handler, g_basename (file), TRUE);
+			tmp = ext->handler->find (ext->handler, base, TRUE);
 		if (tmp)
 			file = tmp;
+		g_free (base);
 	}
 
 	mtm_ext_set_file (ext, file);
@@ -312,14 +317,6 @@ editor_page_set_file_list (MtmConfigGui *gui, const gchar **file_list, EditorPag
 	}
 }
 
-static void
-editor_page_ext_changed (MtmConfigGui *gui, MtmExt *ext, EditorPage *page)
-{
-	g_return_if_fail (MTM_IS_CONFIG_GUI (gui));
-	g_return_if_fail (MTM_IS_EXT (ext));
-	g_return_if_fail (IS_EDITOR_PAGE (page));
-}
-
 static void
 editor_page_ext_enabled (GtkToggleButton *button, EditorPage *page)
 {
