@@ -22,14 +22,14 @@ scale_aspect (GdkPixbuf *buf)
 	else if (rwidth > rheight)
 	{
 		width = SCALE_WIDTH;
-		height = SCALE_HEIGHT * (((double)rheight)/rwidth);
+		height = SCALE_WIDTH * (((double)rheight)/(double)rwidth);
 	}
 	else
 	{
 		height = SCALE_HEIGHT;
-		width = SCALE_WIDTH * (((double)rwidth)/rheight);
+		width = SCALE_HEIGHT * (((double)rwidth)/(double)rheight);
 	}
-
+	g_print ("%i %i %i %i\n", rwidth, rheight, width, height);
 	return gdk_pixbuf_scale_simple (buf, width, height, GDK_INTERP_BILINEAR);
 }
 		
@@ -45,15 +45,15 @@ screenshot_grab (const gchar *filename)
 
 	/* Say cheese! */
 	root = gdk_get_default_root_window ();
-	gdk_window_get_size (root, &width, &height);
+	gdk_drawable_get_size (GDK_DRAWABLE (root), &width, &height);
 			
 	buf = gdk_pixbuf_get_from_drawable (NULL, root, NULL,
 		       			    0, 0, 0, 0, width, height);
 	scaled = scale_aspect (buf);
-	gdk_pixbuf_unref (buf);
+	g_object_unref (G_OBJECT (buf));
 
 	result = save_png (scaled, filename);
-	gdk_pixbuf_unref (scaled);
+	g_object_unref (G_OBJECT (scaled));
 	
 	return result;
 }
