@@ -42,8 +42,8 @@ typedef struct
 {
 	MtmExt *ext;
 	GladeXML *xml;
-	gboolean realized;
 	BGApplier *applier;
+	gboolean realized;
 } ConfigPreview;
 
 #define MONITOR_CONTENTS_X 20
@@ -51,6 +51,7 @@ typedef struct
 #define MONITOR_CONTENTS_WIDTH 157
 #define MONITOR_CONTENTS_HEIGHT 111
 
+#if 0
 static gchar**
 generate_file_list (void)
 {
@@ -92,6 +93,7 @@ generate_file_list (void)
 
 	return ret;
 }
+#endif
 
 static void
 destroy_cb (MtmConfigGui *gui, ConfigPreview *preview)
@@ -105,7 +107,7 @@ destroy_cb (MtmConfigGui *gui, ConfigPreview *preview)
 static void
 update_preview (ConfigPreview *preview)
 {
-	if (!(preview->realized && preview->ext))
+	if (!(preview->ext && preview->realized))
 		return;
 	bg_applier_apply_prefs (preview->applier, bg_ext_handler_get_config (BG_EXT_HANDLER (preview->ext->handler)));
 }
@@ -123,13 +125,14 @@ update_widgets (ConfigPreview *preview)
 	g_return_if_fail (preview->ext != NULL);
 	
 	handler = mtm_ext_get_handler (preview->ext);
-	gtk_object_set (GTK_OBJECT (handler), "ext_context", preview->ext, NULL);
-	gtk_object_get (GTK_OBJECT (handler), "Color1", &color1,
-					      "Color2", &color2,
-					      "ColorGradient", &gradient,
-					      "GradientType", &gtype,
-					      "WallpaperLayout", &ltype,
-					      NULL);
+	g_object_set (G_OBJECT (handler), "ext_context", preview->ext, NULL);
+	g_object_get (G_OBJECT (handler),
+		      "Color1", &color1,
+		      "Color2", &color2,
+		      "ColorGradient", &gradient,
+		      "GradientType", &gtype,
+		      "WallpaperLayout", &ltype,
+		      NULL);
 
 	w = glade_xml_get_widget (preview->xml, "colorpicker1");
 	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (w),
@@ -152,18 +155,12 @@ ext_changed_cb (MtmConfigGui *gui, MtmExt *ext, ConfigPreview *preview)
 	BGPreferences *prefs;
 	g_return_if_fail (preview != NULL);
 
+	g_object_set (G_OBJECT (preview->ext->handler), "ext_context", ext, NULL);
 	prefs = bg_ext_handler_get_config (BG_EXT_HANDLER (preview->ext->handler));
-	g_free (prefs->wallpaper_filename);
 	if (ext->file)
-	{
-		prefs->wallpaper_filename = g_strdup (ext->file);
 		prefs->wallpaper_enabled = TRUE;
-	}
 	else
-	{
-		prefs->wallpaper_filename = NULL;
 		prefs->wallpaper_enabled = FALSE;
-	}
 
 	update_widgets (preview);
 	update_preview (preview);
@@ -178,14 +175,6 @@ set_ext_cb (MtmConfigGui *gui, MtmExt *ext, ConfigPreview *preview)
 	update_preview (preview);
 }
 
-static void
-realize_cb (GtkWidget *pixmap, ConfigPreview *preview)
-{
-	g_return_if_fail (preview != NULL);
-	preview->realized = TRUE;
-	update_preview (preview);
-}
-
 static void
 set_ext_arg (ConfigPreview *preview, gchar *arg, gboolean is_int,
 	     gpointer pvalue, int ivalue)
@@ -196,12 +185,12 @@ set_ext_arg (ConfigPreview *preview, gchar *arg, gboolean is_int,
 	if (!preview->ext)
 		return;
 
-	gtk_object_set (GTK_OBJECT (preview->ext->handler), "ext_context",
-			preview->ext, NULL);
+	g_object_set (G_OBJECT (preview->ext->handler),
+		      "ext_context", preview->ext, NULL);
 	if (is_int)
-		gtk_object_set (GTK_OBJECT (preview->ext->handler), arg, ivalue, NULL);
+		g_object_set (G_OBJECT (preview->ext->handler), arg, ivalue, NULL);
 	else
-		gtk_object_set (GTK_OBJECT (preview->ext->handler), arg, pvalue, NULL);
+		g_object_set (G_OBJECT (preview->ext->handler), arg, pvalue, NULL);
 
 	update_preview (preview);
 }
@@ -238,7 +227,7 @@ color2_set_cb (GnomeColorPicker *cp, guint r, guint g, guint b, guint a,
 static void
 pattern_set_cb (GtkMenuItem *item, ConfigPreview *preview)
 {
-	orientation_t type = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (item), "index"));
+	orientation_t type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "index"));
 	gboolean gradient;
 	
 	if (type == 0)
@@ -254,7 +243,7 @@ pattern_set_cb (GtkMenuItem *item, ConfigPreview *preview)
 static void
 align_set_cb (GtkMenuItem *item, ConfigPreview *preview)
 {
-	wallpaper_type_t type = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (item), "index"));
+	wallpaper_type_t type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "index"));
 	set_ext_arg (preview, "WallpaperLayout", TRUE, NULL, type);
 }
 
@@ -277,25 +266,25 @@ connect_menu (gchar *wname, GtkSignalFunc func, ConfigPreview *preview)
 	for (l = GTK_MENU_SHELL (menu)->children; l != NULL; l = l->next)
 	{
 		item = GTK_MENU_ITEM (l->data);
-		gtk_object_set_data (GTK_OBJECT (item), "index", GINT_TO_POINTER (index++));
-		gtk_signal_connect (GTK_OBJECT (item), "activate", func, preview);
+		g_object_set_data (G_OBJECT (item), "index", GINT_TO_POINTER (index++));
+		g_signal_connect (G_OBJECT (item), "activate", (GCallback) func, preview);
 	}
 }
 
+static void
+realized_cb (GtkWidget *w, ConfigPreview *preview)
+{
+	preview->realized = TRUE;
+	update_preview (preview);
+}
+
 MtmConfigGui*
 bg_config_gui_new (MtmGuiHandler *handler)
 {
 	GladeXML *xml;
 	GtkWidget *w;
-	gchar *imfile;
-	GdkPixbuf *buf;
-	GtkWidget *pixmap;
-	GdkPixmap *pmap;
-	GdkBitmap *bmap;
 	MtmConfigGui *gui;
-	gchar **files;
 	ConfigPreview *preview;
-	GtkWidget *box, *hbox, *vbox;
 
 	xml = glade_xml_new (GLADEFILE, "hbox1", NULL);
 	if (!xml)
@@ -319,27 +308,26 @@ bg_config_gui_new (MtmGuiHandler *handler)
 
 	w = glade_xml_get_widget (xml, "preview_frame");
 	gtk_container_add (GTK_CONTAINER (w), bg_applier_get_preview_widget (preview->applier));
+	g_signal_connect (G_OBJECT (w), "realize", (GCallback) realized_cb, preview);
 	
-	gtk_signal_connect_after (GTK_OBJECT (gui), "destroy",
-			          GTK_SIGNAL_FUNC (destroy_cb), preview);
+	g_signal_connect_after (G_OBJECT (gui), "destroy",
+			          (GCallback) destroy_cb, preview);
 	
-	gtk_signal_connect (GTK_OBJECT (gui), "set_ext",
-			    GTK_SIGNAL_FUNC (set_ext_cb), preview);
-	gtk_signal_connect (GTK_OBJECT (gui), "ext_modified",
-			    GTK_SIGNAL_FUNC (ext_changed_cb), preview);
-	gtk_signal_connect (GTK_OBJECT (pixmap), "realize",
-			    GTK_SIGNAL_FUNC (realize_cb), preview);
+	g_signal_connect (G_OBJECT (gui), "set_ext",
+			    (GCallback) set_ext_cb, preview);
+	g_signal_connect (G_OBJECT (gui), "ext_modified",
+			    (GCallback) ext_changed_cb, preview);
 
 	w = glade_xml_get_widget (xml, "colorpicker1");
-	gtk_signal_connect (GTK_OBJECT (w), "color_set",
-			    GTK_SIGNAL_FUNC (color1_set_cb), preview);
+	g_signal_connect (G_OBJECT (w), "color_set",
+			    (GCallback) color1_set_cb, preview);
 	w = glade_xml_get_widget (xml, "colorpicker2");
-	gtk_signal_connect (GTK_OBJECT (w), "color_set",
-			    GTK_SIGNAL_FUNC (color2_set_cb), preview);
+	g_signal_connect (G_OBJECT (w), "color_set",
+			    (GCallback) color2_set_cb, preview);
 	connect_menu ("pattern_menu",
-		      GTK_SIGNAL_FUNC (pattern_set_cb), preview);
+		      (GCallback) pattern_set_cb, preview);
 	connect_menu ("align_menu",
-		      GTK_SIGNAL_FUNC (align_set_cb), preview);
+		      (GCallback) align_set_cb, preview);
 
 	gtk_widget_show_all (w);
 
